@@ -15,31 +15,6 @@ from keras.preprocessing.image import (
     DirectoryIterator
 )
 
-def extract_date(df, date_column_name):
-    '''
-    Function to extract the data of a date, from a column that does not have date format.
-    The function also creates a column for date and year.
-
-    Parameters
-    ----------
-    df : dataframe
-        It is the dataset where the column that we have to extract the data is located.
-    date_column_name : str
-        is the column that has data in string. From here the data is extracted and converted to date format.
-
-    
-    Return
-    ----------
-        df : Dataframe with the changes made
-
-    '''
-    match = re.search(r'\d{4}.\d{2}.\d{2}', date_column_name)
-    date = datetime.strptime(match.group(), '%Y-%m-%d').date()
-
-    df['Year'] = df[date_column_name].dt.year
-    df['Month'] = df[date_column_name].dt.month
-    
-    return df
 
 def list_categorical_columns(df):
     '''
@@ -64,6 +39,7 @@ def list_categorical_columns(df):
 
 
 
+
 def uniq_value(list_values:list):
     '''
     Function returning the unique values from a list.
@@ -74,11 +50,13 @@ def uniq_value(list_values:list):
     ----------
     unique: list of unique values
     '''
+
     unique = []
     for i in list_values:
         if i not in unique:
-            unique.extend(list_values)
-    return unique
+            unique.append(i)
+        return unique
+
 
 def last_columndf(df,feature):
     '''
@@ -278,7 +256,7 @@ def load_imgs(path, im_size:int):
                 filenames.append(file)
                 if file [-4:] == '.jpg' or file [-4:] == '.png':
                     # Read the image in color.
-                    image = imread(subdir + '\\' + file)
+                    image = imread(subdir + '/' + file)
                     # Resize the image.
                     smallimage = cv2.resize(image, (im_size, im_size)) 
                     # Save the images in the X variable.
@@ -411,7 +389,7 @@ class ImageDataGen(ImageDataGenerator):
         shuffle=True,
         sample_weight=None,
         seed=None,
-        save_to_dir='./aug',
+        save_to_dir=None,
         save_prefix='',
         save_format='png',
         ignore_class_split=False,
@@ -844,4 +822,40 @@ class ImageDataGen(ImageDataGenerator):
                 next(generator)
                 images_generated += batch_size
 
-        return generator
\ No newline at end of file
+        return generator
+
+
+def Nantreatment(data, replace=True, replace_value='None', replace_numeric_with_mean=False):
+    '''
+    Function:
+    -----------
+    This function works with the Nan's inside of a DataFrame, wich give you diferents option when you try to work with them
+    Parameters:
+    -----------
+    data: Pandas DataFrame
+        Data that the function is going to analyze 
+    replace: bool
+        Depends if its True or False, True gives you the Nan replace by a zero or the mean if the column is a number
+        and None if the column is an object,in case that replace is False, drops all the Nan's in the DataFrame
+    replace_numeric_with_mean: bool
+        choose if you want to Nan with 0 or with the mean
+    
+    Returns:
+    -----------
+    Pandas DataFrame
+        The function returns a copy of the input DataFrame with NaN values replaced or dropped.
+    '''
+
+
+    if replace:
+        if replace_numeric_with_mean:
+            data = data.fillna(value=data.mean())
+        else:
+            for name in data.select_dtypes(include=[np.number]):
+                data[name] = data[name].fillna(value=0)
+        for name in data.select_dtypes(include=[object]):
+            data[name] = data[name].fillna(replace_value)
+    else:
+        data = data.dropna()
+    
+    return data.reset_index(drop=True)
\ No newline at end of file
